@@ -211,70 +211,6 @@ update.HLfit <- function(object, formula., ..., evaluate = TRUE) {
   return(main_terms_info)    ############################# no longer true: 'of class "HLframes", the class set to object$HLframes' 
 }
 
-if (FALSE) {
-  .bind_resp <- function(newresp, object, re_data=object$data, only_resp=FALSE) {
-  mf <- model.frame(object)
-  #form <- formula.HLfit(object, which="hyper")
-  respnames <- c()
-  if (inherits(mf,"list")) { # list of data.frames (with attributes): mv case : then newresp is assumed to be the result of simulate, an overlong vector.
-    nobs <- nrow(object$data)
-    frst <- 0L
-    for (mv_it in seq_along(mf)) {
-      lst <- frst+nobs
-      resp_i <- newresp[(frst+1L):lst]
-      frst <- lst
-      Y <- model.response(mf[[mv_it]])
-      if (NCOL(Y)==2L) {
-        colY <- colnames(Y)
-        if (colY[1L]!="") re_data[,colY[1L]] <- resp_i
-        if (colY[2L]!="") re_data[,colY[2L]] <- rowSums(Y)-resp_i
-        respnames <- c(respnames, colY)
-      } else { # colnames(Y) is typically NULL
-        if (inherits(mf[[mv_it]][[1L]],"AsIs")) {
-          stop("the response of the original fit is as 'AsIs' term, I(.), which is not handled by code updating response.")
-        } else {
-          coly <- colnames(mf[[mv_it]])[1L]
-          re_data[coly] <- resp_i
-          respnames <- c(respnames, coly)
-        } 
-      }
-    }
-    if (only_resp) re_data <- re_data[,respnames,drop=FALSE]
-    return(re_data)
-  }
-  Y <- model.response(mf)
-  if (NCOL(Y)==2L) { ## paste(form[[2L]])[[1L]]=="cbind"
-    # model.frame is a data frame whose 1st element is a 2-col matrix with unamed first column
-    # model.response() extracts this matrix:
-    # If formula is cbind(npos,nneg) ~... the two columns have names "npos", "nneg"
-    # If formula is cbind(npos,ntot-npos) ~... the two columns have names "npos", ""
-    # If formula is cbind(ntot-nneg,nneg) ~... the two columns have names "", "nneg"
-    colY <- colnames(Y)
-    if (colY[1L]!="") re_data[,colY[1L]] <- newresp
-    if (colY[2L]!="") re_data[,colY[2L]] <- rowSums(Y)-newresp
-    # any "ntot" col is left unchanged. In particular, from # cbind(ntot-nneg,nneg)
-    #  thsi code changes nneg to ntot-newresp so that ntot-nneg will be newresp
-    if (only_resp) re_data <- re_data[,colY]
-  } else { # colnames(Y) is typically NULL
-    ## : from a formula of the form formula I(<fn>(var...)) ~ ... colnames(mf)[1L] is "I(<fn>(var...))" 
-    # for a variable of class 'AsIs' which is NOT used in the refit... 
-    if (inherits(mf[[1L]],"AsIs")) {
-      stop("the response of the original fit is as 'AsIs' term, I(.), which is not handled by code updating response.")
-      # the alternative would be to change internally the lhs of the formula...
-    } else {
-      if (only_resp) {
-        re_data <- data.frame(newresp)
-        colnames(re_data) <- colnames(mf)[1L]
-      } else re_data[colnames(mf)[1L]] <- newresp
-    } 
-  }
-  return(re_data)
-  }
-  
-  .update_data  <- function(object, newresp) .bind_resp(newresp=newresp, object=object)
-  
-}
-
 
 update_resp <- function(object, newresp, ...,  evaluate = TRUE) {
   if (is.null(re_call <- getCall(object))) stop("need an object with call component")
@@ -298,15 +234,6 @@ update_resp <- function(object, newresp, ...,  evaluate = TRUE) {
   else re_call
 }
 
-if (FALSE) {
-  x = simulate(fittedModel)
-  refit.HLfit <- function(object, newresp, ...) { ## consistent with lme4:: generic function
-    update_resp(object, newresp)
-  }
-  refit.HLfit(fittedModel, x)
-  remove(refit.HLfit)
-}
-
 # Fix intercept issue in local def of stats::terms.formula
 .fixFormulaObject <- function (object) { # object is a formula object not a fit object
   Terms <- terms(object)
