@@ -11,7 +11,7 @@ if (requireNamespace("Infusion",quietly=TRUE)) {
   if (do.call("require",list(package="Rmixmod", quietly = TRUE))) {
     example("example_raw",package="Infusion",ask=FALSE) ## detected calc_logdisp_cov issues 
   } else {
-    cat( "package 'Rmixmod' not available, cannot run Infusion test.\n" )
+    cat( crayon::bgGreen("package 'Rmixmod' not available, cannot run Infusion test.\n" ))
   }
 }
 
