@@ -1,9 +1,9 @@
 cat(crayon::yellow("\ntest-mv:"))
 
 if (FALSE) {
-  source(paste0(projpath(),"/package/tests/testthat/nestedFiles/test-mv-nested.R"))
-  source(paste0(projpath(),"/package/tests/testthat/nestedFiles/test-composite-nested.R"))
-  source(paste0(projpath(),"/package/tests/testthat/nestedFiles/test-mv-corrFamily.R"))
+  source(paste0(spaMM::projpath(),"/package/tests/testthat/extralong/test-mv-extra.R"))
+  source(paste0(spaMM::projpath(),"/package/tests/testthat/extralong/test-composite-extra.R"))
+  source(paste0(spaMM::projpath(),"/package/tests/testthat/extralong/test-mv-corrFamily.R"))
 } else {
   data("wafers")
   me <- fitme(y ~ 1+(1|batch), family=Gamma(log), data=wafers)
@@ -25,7 +25,9 @@ if (FALSE) {
     (zut1 <- fitmv(submodels=list(mod1=list(formula=y ~ 1+(1|batch), family=Gamma(log),resid.model= ~  1+(1|batch)),
                                   mod2=list(formula=y2 ~ 1+(1|batch), family=Gamma(log))), 
                    data=wafmv))
-    confint(zut1,"(Intercept)_1") # __F I X M E__ messy display
+    confint(zut1,"(Intercept)_1") 
+    get_fittedPars(zut1) # handling of heterogeneous resid.models
+    # numInfo(zut1) # mixed resid.model issue, not specific to mv...
   }
   
   data("recond") # private data set for test
