@@ -9,7 +9,7 @@ if(requireNamespace("lme4", quietly = TRUE)) {
   try(testthat::expect_equal(predict(res)[1:6,],predict(res,newdata=sleepstudy[1:6,],re.form= ~ (Days|Subject))[,1])) 
   ## tests of predVar with re.form and ranCoefs in test-devel-predVar-ranCoefs.R
   ## a bit slow but detects many problem: (+ effect of refit$lambda)
-  if (FALSE) { # \label{ares_bobyqa_ssprec} # this case produced a bug before found in .calc_cov_from_ranCoef (+ bobyqa margin is used in the bobyqa_wrapper + ).
+  if (FALSE) { # \label{ares_bobyqa_spprec} # this case produced a bug before found in .calc_cov_from_ranCoef (+ bobyqa margin is used in the bobyqa_wrapper + ).
     #spaMM.options(allow_augZXy=TRUE) # make sure of this; even if it's the default
     oldopt <- spaMM.options(optimizer="bobyqa", sparse_precision=TRUE)
     (ares <- fitme(Reaction ~ Days + AR1(1|Days) + (Days|Subject), data = sleepstudy, verbose=c(TRACE=TRUE)))
